@@ -7,6 +7,7 @@ from spark_basic_python.com.tf56.util import configloader
 from spark_basic_python.com.tf56.sparkbasic.contextfactory import ContextFactory
 
 config = configloader.buildconfig("pg.datasource.ini")
+cf = ContextFactory()
 
 
 class DataAccess:
@@ -28,7 +29,7 @@ class DataAccess:
             cursor = conn.cursor()
             cursor.execute(sql)
             pdf = pd.DataFrame(cursor.fetchall())
-            sdf = ContextFactory.build_spark_context().createDataFrame(pdf)
+            sdf = cf.build_spark_context().createDataFrame(pdf)
         except psycopg2.DatabaseError, exception:
             print (exception)
             sys.exit(1)
@@ -39,4 +40,4 @@ class DataAccess:
     # return: 以spark dataFrame的数据结构返回结果集
     @staticmethod
     def query_hive(sql):
-        return ContextFactory.build_hive_context().sql(sql)
+        return cf.build_hive_context().sql(sql)
